Learn R Programming

lionfish (version 1.0.27)

check_conda_env: Check Whether 'anaconda' Environment Exists

Description

Checks if 'anaconda' environment of the given name is installed and returns TRUE if so.

Usage

check_conda_env(env_name = "r-lionfish")

Value

boolean

Arguments

env_name

a string that defines the name of the 'anaconda' environment reticulate uses.

Examples

Run this code
check_conda_env(env_name="r-lionfish")

Run the code above in your browser using DataLab