Learn R Programming

lionfish (version 1.0.27)

check_venv: Check Whether Virtual 'python' Environment Exists

Description

Checks whether virtual 'python' environment of a given name exists an returns TRUE if it does.

Usage

check_venv(env_name = "r-lionfish")

Value

boolean

Arguments

env_name

a string that defines the name of the 'python' environment reticulate uses.

Examples

Run this code
check_venv(env_name="r-lionfish")

Run the code above in your browser using DataLab