powered by
Checks if 'anaconda' environment of the given name is installed and returns TRUE if so.
check_conda_env(env_name = "r-lionfish")
boolean
a string that defines the name of the 'anaconda' environment reticulate uses.
check_conda_env(env_name="r-lionfish")
Run the code above in your browser using DataLab