powered by
Checks whether virtual 'python' environment of a given name exists an returns TRUE if it does.
check_venv(env_name = "r-lionfish")
boolean
a string that defines the name of the 'python' environment reticulate uses.
check_venv(env_name="r-lionfish")
Run the code above in your browser using DataLab