get_guided_holes_better_history: Get Guided Tour-Holes-Better History
Description
Returns a guided tour with the holes index and the 'search_better' argument
to the python' backend. This guided tour is generated with the 'tourr'
functions 'save_history' and 'guided_tour'.
Usage
get_guided_holes_better_history(data, dimension)
Value
history object containing the projections of the requested tour