Learn R Programming

lionfish (version 1.0.27)

get_guided_holes_history: Get Guided Tour-Holes History

Description

Returns a guided tour with the holes index to the python' backend. This guided tour is generated with the 'tourr' functions 'save_history' and 'guided_tour'.

Usage

get_guided_holes_history(data, dimension)

Value

history object containing the projections of the requested tour

Arguments

data

the dataset to calculate the projections with.

dimension

1 for a 1d tour or 2 for a 2d tour

Examples

Run this code
data("flea", package = "tourr")
flea <- flea[-7]
get_guided_holes_history(flea, 2)

Run the code above in your browser using DataLab