get_guided_holes_history: Get Guided Tour-Holes History
Description
Returns a guided tour with the holes index to the python' backend. This
guided tour is generated with the 'tourr' functions 'save_history' and
'guided_tour'.
Usage
get_guided_holes_history(data, dimension)
Value
history object containing the projections of the requested tour