Learn R Programming

lionfish (version 1.0.27)

get_local_history: Get Local Tour History

Description

Returns a local tour based on currently displayed projection(s) to the 'python' backend. This local tour is generated with the 'tourr' functions 'save_history' and 'local_tour'.

Usage

get_local_history(data, starting_projection)

Value

history object containing the projections of the requested tour

Arguments

data

the dataset to calculate the projections with. In practice only the two first rows of the dataset are provided as the actual data is not needed.

starting_projection

the initial projection one wants to initiate the local tour from

Examples

Run this code
library(tourr)
data("flea", package = "tourr")
flea <- flea[-7]
prj <- tourr::basis_random(ncol(flea), 2)
get_local_history(flea, prj)

Run the code above in your browser using DataLab