Returns a local tour based on currently displayed projection(s) to the
'python' backend. This local tour is generated with the 'tourr' functions
'save_history' and 'local_tour'.
Usage
get_local_history(data, starting_projection)
Value
history object containing the projections of the requested tour
Arguments
data
the dataset to calculate the projections with. In practice
only the two first rows of the dataset are provided as the actual data is not
needed.
starting_projection
the initial projection one wants to initiate the
local tour from