Learn R Programming

lionfish (version 1.0.27)

risk: Risk Dataset

Description

Risk Dataset

Usage

risk

Arguments

Format

A 563 x 6 array of Likert scale data

Details

Adult Australian residents that have undertaken at least one holiday in the last year, which involved staying away from home for at least four nights, were asked what risks they have taken in the past. The questions were about recreational, health, career, financial, safety and social risk. The response options were on the following: never (1), rarely (2), quite often (3), often (4) or very often (5)

Examples

Run this code
data(risk)
head(risk)

Run the code above in your browser using DataLab